<?php
/*
Plugin Name: CF7 Country by IP
Description: Automatically detect the country and city based on the IP address of the client filling out a Contact Form 7 form.
Version: 1.2
Author: Leo
*/

// Check if Contact Form 7 is active
function is_cf7_active() {
    include_once(ABSPATH . 'wp-admin/includes/plugin.php');
    return is_plugin_active('contact-form-7/wp-contact-form-7.php');
}

// Add shortcode for Contact Form 7 to get country by IP
function custom_cf7_country_by_ip($tag = '') {
    $ip = $_SERVER['REMOTE_ADDR'];
    $country = '';
    $city = '';
    $details = json_decode(file_get_contents("http://ipinfo.io/{$ip}/json"));
    if (isset($details->country)) {
        $country = $details->country;
        $city = $details->city;
    }
    return ($country) ? ($city . ', ' . $country) : '';
}

if (is_cf7_active()) {
    add_action('wpcf7_init', 'custom_add_form_tag_my_source');
    function custom_add_form_tag_my_source() {
        wpcf7_add_form_tag('country_by_ip', 'custom_cf7_country_by_ip');
    }

    add_filter('wpcf7_special_mail_tags', 'your_special_mail_tag', 10, 3);
    function your_special_mail_tag($output, $name, $html) {
        if ('country_by_ip' == $name) {
            $output = custom_cf7_country_by_ip();
        }
        return $output;
    }
}

// Add menu item to WordPress admin
add_action('admin_menu', 'cf7_country_by_ip_menu');
function cf7_country_by_ip_menu() {
    add_menu_page('CF7 Country by IP', 'CF7 Country by IP', 'manage_options', 'cf7-country-by-ip', 'cf7_country_by_ip_page');
}

function cf7_country_by_ip_page() {
    ?>
    <div class="wrap">
        <h1>CF7 Country by IP</h1>
        <p>在你的 Contact Form 7 表单中使用短代码 <code class="copy-code" data-code="[country_by_ip]">[country_by_ip]</code> 以显示基于客户IP地址的国家和城市信息。</p>
        <p>在你的表单中使用短代码 <code class="copy-code" data-code="[_remote_ip]">[_remote_ip]</code> 以显示客户的IP地址。</p>
        <?php if (!is_cf7_active()) : ?>
            <div class="notice notice-error">
                <p>Contact Form 7 未激活。短代码 <code>[country_by_ip]</code> 和 <code>[_remote_ip]</code> 将无法工作，直到 Contact Form 7 被激活。</p>
            </div>
        <?php endif; ?>
    </div>
    <script>
        document.addEventListener('DOMContentLoaded', function() {
            var copyCodes = document.querySelectorAll('.copy-code');
            copyCodes.forEach(function(code) {
                code.style.cursor = 'pointer';
                code.addEventListener('click', function() {
                    var textArea = document.createElement('textarea');
                    textArea.value = code.getAttribute('data-code');
                    document.body.appendChild(textArea);
                    textArea.select();
                    document.execCommand('copy');
                    document.body.removeChild(textArea);
                    alert('短代码已复制: ' + code.getAttribute('data-code'));
                });
            });
        });
    </script>
    <?php
}

// Add author link to plugin meta
add_filter('plugin_row_meta', 'cf7_country_by_ip_plugin_meta', 10, 2);
function cf7_country_by_ip_plugin_meta($links, $file) {
    if ($file == plugin_basename(__FILE__)) {
        $links[] = '<a href="https://cnseodigital.com/" target="_blank">View details</a>';
    }
    return $links;
}
